tuplettools.Tuplet
==================

.. abjad-lineage:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet

.. autoclass:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.contents_duration
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.descendants
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.duration_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.has_non_power_of_two_denominator
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.has_power_of_two_denominator
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.implied_prolation
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.is_augmentation
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.is_diminution
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.is_trivial
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.leaves
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.lineage
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.multiplied_duration
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.music
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.override
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.parent
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.parentage
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.preprolated_duration
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.prolated_duration
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.prolation
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.ratio_string
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.set
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.spanners
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.start_offset
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.start_offset_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.stop_offset
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.stop_offset_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.storage_format
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.timespan
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.timespan_in_seconds
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.force_fraction
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.is_invisible
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.is_parallel
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.multiplier
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.preferred_denominator
   :noindex:

Methods
-------

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.append
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.extend
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.index
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.insert
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.pop
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.remove
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__add__
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__contains__
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__delitem__
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__eq__
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__ge__
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__getitem__
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__gt__
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__iadd__
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__imul__
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__le__
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__len__
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__lt__
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__mul__
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__ne__
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__radd__
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__repr__
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__rmul__
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__setitem__
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__str__
   :noindex:
